@@ -1,9 +1,8 @@
 """
 All of the functionality of this package is through the function StarSolve(). 
 Call help(binarystarsolve.binarystarsolve.StarSolve) for the associated Docstring.
-
-For more a detailed description of how to use this package, please read the ReadMe.
-https://github.com/NickMilsonPhysics/binarystarsolve/blob/master/README.md
+For a more detailed description of how to use this package, please read the ReadMe.
+https://github.com/NickMilsonPhysics/BinaryStarSolver/blob/master/README.md
 """
 
 # Import statements
@@ -16,11 +15,10 @@ import sys
 
 def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = False,graphs = True, X = None, err = None,shift = False):
     """
-	
-
-	Please first read the read me at:
-	https://github.com/NickMilsonPhysics/binarystarsolve/blob/master/README.md
-
+    
+        Please first read the read me at:
+       	https://github.com/NickMilsonPhysics/BinaryStarSolver/blob/master/README.md
+        
         Keyword Arguments: 
             
         ** Note some arguments pertain to when parameters of the primary are
@@ -714,7 +712,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
         temp *= ((V0 + ((np.cos(v + w) + e*np.cos(w))*K)) - V)*weight
         return sum(2*temp)
     
-    def PrimarySolve(period = None, Pguess = None,covariance = False, graphs = True):
+    def PrimarySolve(period = None, Pguess = None,covariance = False, graphs = True,correction = False):
         """
         Solves for orbital parameters from radial velocity data
         
@@ -744,6 +742,8 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
         # """
         if Pguess != None:
             period = Pguess
+        if not correction:
+            print("Finding initial guesses...")
         x = x0(period) # initial guess
         if x == None:
             print('User must provide an estimate for P.')
@@ -762,6 +762,8 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             var = 6
     
         l = 3    
+        if not correction:
+            print("Minimizing...")
         while True: # perfoming minimization
             xLast = x
             ang = true(time, T0, e, P, ec = True)
@@ -813,7 +815,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
                 V0, K, w, e, T0, P = x
             else:
                 V0, K, w, e, T0 = x
-            
+           
             
             if SumSquared(x, P) < SumSquared(xLast, P): # if params got better
                 if abs(SumSquared(xLast, P) - SumSquared(x, P)) < 0.01 or abs(1-(SumSquared(x, P)/SumSquared(xLast, P))) < 1e-3:
@@ -886,7 +888,9 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             phasesfit = np.array(sorted(phasesfit,key=lambda l:l[0]))
             
             # average velocity, γ
-            gam = np.zeros(len(phases)) + x[0] # average velocity
+            gam = np.zeros(100) + x[0] # average velocity
+            timeLin = np.linspace(min(times), max(times),100)
+            phaseLin = np.linspace(0,1,100)
             
             # time plot
             plt.figure()
@@ -894,7 +898,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             plt.plot(times, fit, color = "orange")
             plt.xlabel("RJD")
             plt.ylabel("Velocity (km s$^{-1}$)")
-            plt.plot(times, gam, ls = "--", color = "black")
+            plt.plot(timeLin, gam, ls = "--", color = "black")
             
             # phase plot
             plt.figure()
@@ -902,7 +906,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             plt.plot(phasesfit[:,0], phasesfit[:,1], color = "orange")
             plt.xlabel("Phase")
             plt.ylabel("Velocity (km s$^{-1}$)")
-            plt.plot(phases, gam, ls = "--", color = "black")
+            plt.plot(phaseLin, gam, ls = "--", color = "black")
         
         # rounding
         V0 = sigFig(x[0], 5)
@@ -982,6 +986,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
         params = V0, K, w, e, T0, P
         ang = true(time, T0, e, P, ec = True)
         
+        print("Minimizing...")
         while True:
             paramsLast = params
             varLast = params[0], params[1]
@@ -998,7 +1003,6 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             
             params = var[0], var[1], w, e, T0, P
             
-            
             if abs(SumSquared(paramsLast, None) - SumSquared(params, None)) < 0.01:
                     break
         
@@ -1040,7 +1044,9 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             phasesfit = np.array(sorted(phasesfit,key=lambda l:l[0]))
             
             # average velocity, γ
-            gam = np.zeros(len(phases)) + x[0] # average velocity
+            gam = np.zeros(100) + x[0] # average velocity
+            timeLin = np.linspace(min(times), max(times),100)
+            phaseLin = np.linspace(0,1,100)
             
             # time plot
             plt.figure()
@@ -1048,7 +1054,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             plt.plot(times,fit, color = "orange")
             plt.xlabel("RJD")
             plt.ylabel("Velocity (km s$^{-1}$)")
-            plt.plot(times,gam, ls = "--", color = "black")
+            plt.plot(timeLin,gam, ls = "--", color = "black")
             
             # phase plot
             plt.figure()
@@ -1056,7 +1062,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
             plt.plot(phasesfit[:,0] ,phasesfit[:,1], color = "orange")
             plt.xlabel("Phase")
             plt.ylabel("Velocity (km s$^{-1}$)")
-            plt.plot(phases,gam,ls = "--", color = "black")
+            plt.plot(phaseLin,gam,ls = "--", color = "black")
         
         if err[0] != None: # if user inputted errors   
             err[1] += 0.01 # adding error from newtons method onto K error
@@ -1145,6 +1151,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
         return (origSets,mask)
     
     if data.shape[1] >= 4: # if γ correcting is required
+        print("Correcting sub-dataset offsets...")
         splitSets, splitMask = split() # splitting sets
         contenders = [] # holds if a data set could be the best
         
@@ -1182,7 +1189,7 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
         weight = splitSets[:,2,contenders[0]][splitMask[:,2,contenders[0]]]   
         N = len(time)
         # finding parameters for "best" data set
-        X,err = PrimarySolve(period = Period, covariance = False, graphs = False)
+        X,err = PrimarySolve(period = Period, covariance = False, graphs = False,correction = True)
         sets = list(set(setNum))
         sets.remove(setNum[contenders[0]]) # removing the "best" set from sets
         for i in sets: # shifting other data sets
@@ -1229,3 +1236,4 @@ def StarSolve(data_file,star = "primary",Period=None,Pguess=None, covariance = F
     else:
         print("Please let the parameter, star, be the string \"primary\" or \"secondary\"")
         sys.exit()
+    
\ No newline at end of file
